==> taboola_sdk-0.2.1.tar.gz: android/src/main/java/com/taboola/flutter/TaboolaSdkPlugin.java <==
package com.taboola.flutter;


import android.content.Context;

import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.MethodCall;

/**
 * FIXME: Open Flutter issue, adding MethodChannels to packages (plugin inside plugin essentially)
 * In order for Android to recognize these imports I added the flutter.jar.
 *  This might cause issues working with the Flutter project itself, might have to comment out dependency before building.
 *
 *  Current patchy workflow: Don't forget to comment in/out flutter.jar in Build.Gradle.
 *  Source: https://github.com/flutter/flutter/issues/19830
 */
public class TaboolaSdkPlugin implements FlutterPlugin, MethodCallHandler {
    private static Taboola sTaboola;

    @Override
    public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
        final MethodChannel channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "taboola_sdk");
        channel.setMethodCallHandler(new com.taboola.flutter.TaboolaSdkPlugin());

        if (sTaboola == null){
            sTaboola = new Taboola(flutterPluginBinding.getApplicationContext());
        }
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    @SuppressWarnings("deprecation")
    public static void registerWith(io.flutter.plugin.common.PluginRegistry.Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "taboola_sdk");
        channel.setMethodCallHandler(new com.taboola.flutter.TaboolaSdkPlugin());

        if (sTaboola == null){
            sTaboola = new Taboola(registrar.context());
        }
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (sTaboola == null) {
            Log.d("TaboolaSdkPlugin", "onMethodCall | sTaboola is null, method called = " + call.method);
            return;
        }

        if (call.method.equals("isUserOptOut")) { //Advertising Id related
            result.success(sTaboola.isLimitedAdTrackingEnabled());
        } else if (call.method.equals("getAdIdOrIdfa")) {
            result.success(sTaboola.getAdvertisingId());
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(FlutterPluginBinding binding) {
    }
}

==> taboola_sdk-0.3.1.tar.gz: android/src/main/java/com/taboola/flutter/TaboolaSdkPlugin.java <==
package com.taboola.flutter;


import android.content.Context;

import android.graphics.Color;
import io.flutter.Log;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.MethodCall;

/**
 * FIXME: Open Flutter issue, adding MethodChannels to packages (plugin inside plugin essentially)
 * In order for Android to recognize these imports I added the flutter.jar.
 *  This might cause issues working with the Flutter project itself, might have to comment out dependency before building.
 *
 * Current patchy workflow: Don't forget to comment in/out flutter.jar in Build.Gradle.
 * Source: https://github.com/flutter/flutter/issues/19830
 */
public class TaboolaSdkPlugin implements FlutterPlugin, MethodCallHandler {
    private static Taboola sTaboola;
    private static Telephony sTelephony;

    private static final String IS_USER_OPT_OUT = "isUserOptOut";
    private static final String GET_AD_ID_OR_IDFA = "getAdIdOrIdfa";
    private static final String GET_ISO_COUNTRY_CODE = "getIsoCountryCode";
    private static final String CHANNEL_NAME = "taboola_sdk";

    @Override
    public void onAttachedToEngine(FlutterPluginBinding flutterPluginBinding) {
        final MethodChannel channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), CHANNEL_NAME);
        channel.setMethodCallHandler(new com.taboola.flutter.TaboolaSdkPlugin());
        Context context = flutterPluginBinding.getApplicationContext();

        if (sTaboola == null) {
            sTaboola = new Taboola(context);
            sTelephony = new Telephony(context);
        }
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    @SuppressWarnings("deprecation")
    public static void registerWith(io.flutter.plugin.common.PluginRegistry.Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "taboola_sdk");
        channel.setMethodCallHandler(new com.taboola.flutter.TaboolaSdkPlugin());
        Context context = registrar.context();
        if (sTaboola == null) {
            sTaboola = new Taboola(context);
            sTelephony = new Telephony(context);
        }
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (sTaboola == null) {
            Log.d("TaboolaSdkPlugin", "onMethodCall | sTaboola is null, method called = " + call.method);
            return;
        }
        switch (call.method) {
            case IS_USER_OPT_OUT:
                result.success(sTaboola.isLimitedAdTrackingEnabled());
                break;
            case GET_AD_ID_OR_IDFA:
                result.success(sTaboola.getAdvertisingId());
                break;
            case GET_ISO_COUNTRY_CODE:
                result.success(sTelephony.getIsoCountryCode());
                break;
            default:
                result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(FlutterPluginBinding binding) {
    }
}
